@@ -1,6 +1,7 @@
 from werkzeug import FileStorage
 from wtforms import FileField as _FileField
 from wtforms import ValidationError
+from wtforms.validators import InputRequired, StopValidation
 
 
 class FileField(_FileField):
@@ -10,13 +11,6 @@ class FileField(_FileField):
     Provides a `has_file()` method to check if its data is a FileStorage
     instance with an actual file.
     """
-    @property
-    def file(self):
-        """
-        :deprecated: synonym for **data**
-        """
-        return self.data
-
     def has_file(self):
         '''Return True iff self.data is a FileStorage with file data'''
         if not isinstance(self.data, FileStorage):
@@ -28,7 +22,7 @@ class FileField(_FileField):
         return self.data.filename not in [None, '', '<fdopen>']
 
 
-class FileRequired(object):
+class FileRequired(InputRequired):
     """
     Validates that field has a file.
 
@@ -37,12 +31,13 @@ class FileRequired(object):
     You can also use the synonym **file_required**.
     """
 
-    def __init__(self, message=None):
-        self.message = message
-
     def __call__(self, form, field):
         if not field.has_file():
-            raise ValidationError(self.message)
+            if self.message is None:
+                message = field.gettext('This field is required.')
+            else:
+                message = self.message
+            raise StopValidation(message)
 
 file_required = FileRequired
 
